httpwriter

package
v7.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 9, 2026 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Analyzer = &analysis.Analyzer{
	Name: "httpwriter",
	Doc:  "Ensures that httputil functions which make use of the writer are immediately followed by a return statement.",
	Requires: []*analysis.Analyzer{
		inspect.Analyzer,
	},
}

Functions

func Run

func Run(pass *analysis.Pass) (any, error)

Types

This section is empty.

Jump to